import { __decorate, __metadata } from 'tslib';
import { defineInjectable, Injectable, inject } from '@angular/core';
import { NgbDateNativeAdapter, NgbDateParserFormatter, NgbDatepickerI18n } from '@ng-bootstrap/ng-bootstrap';
import { isNumber } from 'util';
import { toInteger, padNumber } from '@ng-bootstrap/ng-bootstrap/util/util';

let I18nEsService = class I18nEsService {
    constructor() {
        this.language = "es";
    }
};
I18nEsService.ngInjectableDef = defineInjectable({ factory: function I18nEsService_Factory() { return new I18nEsService(); }, token: I18nEsService, providedIn: "root" });
I18nEsService = __decorate([
    Injectable({
        providedIn: "root"
    })
], I18nEsService);

class DateAdapter extends NgbDateNativeAdapter {
    fromModel(date) {
        if (typeof date === "string") {
            date = new Date(date);
        }
        return date && date.getFullYear
            ? {
                year: date.getFullYear(),
                month: date.getMonth() + 1,
                day: date.getDate()
            }
            : null;
    }
}
class EsDateFormat extends NgbDateParserFormatter {
    parse(value) {
        if (value) {
            const dateParts = value.trim().split("/");
            if (dateParts.length === 1 && isNumber(dateParts[0])) {
                return { day: toInteger(dateParts[0]), month: null, year: null };
            }
            else if (dateParts.length === 2 &&
                isNumber(dateParts[0]) &&
                isNumber(dateParts[1])) {
                return {
                    day: toInteger(dateParts[0]),
                    month: toInteger(dateParts[1]),
                    year: null
                };
            }
            else if (dateParts.length === 3 &&
                isNumber(dateParts[0]) &&
                isNumber(dateParts[1]) &&
                isNumber(dateParts[2])) {
                return {
                    day: toInteger(dateParts[0]),
                    month: toInteger(dateParts[1]),
                    year: toInteger(dateParts[2])
                };
            }
        }
        return null;
    }
    format(date) {
        return date
            ? (isNumber(date.day) ? padNumber(date.day) : "") +
                "/" +
                (isNumber(date.month) ? padNumber(date.month) : "") +
                "/" +
                (isNumber(date.year) ? date.year : "")
            : "";
    }
}
const I18N_VALUES = {
    es: {
        weekdays: ["Lu", "Ma", "Mi", "Ju", "Vi", "Sa", "Do"],
        months: [
            "Ene",
            "Feb",
            "Mar",
            "Abr",
            "May",
            "Jun",
            "Jul",
            "Ago",
            "Sep",
            "Oct",
            "Nov",
            "Dic"
        ],
        dayNames: [
            "Lunes",
            "Martes",
            "Miércoles",
            "Jueves",
            "Viernes",
            "Sábado",
            "Domingo"
        ],
        monthNames: [
            "Enero",
            "Febrero",
            "Marzo",
            "Abril",
            "Mayo",
            "Junio",
            "Julio",
            "Agosto",
            "Septiembre",
            "Octubre",
            "Noviembre",
            "Diciembre"
        ]
    }
};

// Define custom service providing the months and weekdays translations
let DatepickerI18nService = class DatepickerI18nService extends NgbDatepickerI18n {
    constructor(_i18n) {
        super();
        this._i18n = _i18n;
    }
    getWeekdayShortName(weekday) {
        return I18N_VALUES[this._i18n.language].weekdays[weekday - 1];
    }
    getMonthShortName(month) {
        return I18N_VALUES[this._i18n.language].months[month - 1];
    }
    getMonthFullName(month) {
        return I18N_VALUES[this._i18n.language].monthNames[month - 1];
    }
    getDayAriaLabel(date) {
        return `${date.day}/${date.month}/${date.year}`;
    }
};
DatepickerI18nService.ctorParameters = () => [
    { type: I18nEsService }
];
DatepickerI18nService.ngInjectableDef = defineInjectable({ factory: function DatepickerI18nService_Factory() { return new DatepickerI18nService(inject(I18nEsService)); }, token: DatepickerI18nService, providedIn: "root" });
DatepickerI18nService = __decorate([
    Injectable({
        providedIn: "root"
    }),
    __metadata("design:paramtypes", [I18nEsService])
], DatepickerI18nService);

/**
 * Generated bundle index. Do not edit.
 */

export { DateAdapter, DatepickerI18nService, EsDateFormat, I18N_VALUES, I18nEsService };
//# sourceMappingURL=ng-bootstrap-ar.js.map
